@@ -1,7 +1,7 @@
-require 'openssl/cipher'
-require 'cheffish/base_resource'
-require 'openssl'
-require 'cheffish/key_formatter'
+require "openssl/cipher"
+require "cheffish/base_resource"
+require "openssl"
+require "cheffish/key_formatter"
 
 class Chef
   class Resource
@@ -31,7 +31,7 @@ class Chef
 
       # PEM-only
       property :pass_phrase, String
-      property :cipher, OpenSSL::Cipher.ciphers, default: 'DES-EDE3-CBC'
+      property :cipher, OpenSSL::Cipher.ciphers, default: "DES-EDE3-CBC"
 
       # Set this to regenerate the key if it does not have the desired characteristics (like size, type, etc.)
       property :regenerate_if_different, Boolean
@@ -46,7 +46,6 @@ class Chef
         Chef::Log.debug("Overloading #{resource_name}.load_prior_resource with NOOP")
       end
 
-
       action :create do
         create_key(false, :create)
       end
@@ -90,12 +89,12 @@ class Chef
             # Generate a new key
             #
             if current_resource.action == [ :delete ] || regenerate ||
-              (new_resource.regenerate_if_different &&
-                (!current_private_key ||
-                 current_resource.size != new_resource.size ||
-                 current_resource.type != new_resource.type))
+                (new_resource.regenerate_if_different &&
+                 (!current_private_key ||
+                  current_resource.size != new_resource.size ||
+                  current_resource.type != new_resource.type))
 
-             case new_resource.type
+              case new_resource.type
               when :rsa
                 if new_resource.exponent
                   final_private_key = OpenSSL::PKey::RSA.generate(new_resource.size, new_resource.exponent)
@@ -118,7 +117,7 @@ class Chef
               generated_description = " (#{new_resource.size} bits#{new_resource.pass_phrase ? ", #{new_resource.cipher} password" : ""})"
 
               if new_path != :none
-                action = current_resource.path == :none ? 'create' : 'overwrite'
+                action = current_resource.path == :none ? "create" : "overwrite"
                 converge_by "#{action} #{new_resource.type} private key #{new_path}#{generated_description}" do
                   write_private_key(final_private_key)
                 end
@@ -172,7 +171,7 @@ class Chef
         end
 
         def write_private_key(key)
-          ::File.open(new_path, 'w') do |file|
+          ::File.open(new_path, "w") do |file|
             file.chmod(0600)
             file.write(encode_private_key(key))
           end
@@ -180,18 +179,18 @@ class Chef
 
         def new_source_key
           @new_source_key ||= begin
-            if new_resource.source_key.is_a?(String)
-              source_key, source_key_format = Cheffish::KeyFormatter.decode(new_resource.source_key, new_resource.source_key_pass_phrase)
-              source_key
-            elsif new_resource.source_key
-              new_resource.source_key
-            elsif new_resource.source_key_path
-              source_key, source_key_format = Cheffish::KeyFormatter.decode(IO.read(new_resource.source_key_path), new_resource.source_key_pass_phrase, new_resource.source_key_path)
-              source_key
-            else
-              nil
-            end
-          end
+                                if new_resource.source_key.is_a?(String)
+                                  source_key, source_key_format = Cheffish::KeyFormatter.decode(new_resource.source_key, new_resource.source_key_pass_phrase)
+                                  source_key
+                                elsif new_resource.source_key
+                                  new_resource.source_key
+                                elsif new_resource.source_key_path
+                                  source_key, source_key_format = Cheffish::KeyFormatter.decode(IO.read(new_resource.source_key_path), new_resource.source_key_pass_phrase, new_resource.source_key_path)
+                                  source_key
+                                else
+                                  nil
+                                end
+                              end
         end
 
         attr_reader :current_private_key
