@@ -1,4 +1,4 @@
-require 'rspec/matchers'
+require "rspec/matchers"
 
 RSpec::Matchers.define :emit_no_warnings_or_errors do
   match do |recipe|
@@ -7,9 +7,9 @@ RSpec::Matchers.define :emit_no_warnings_or_errors do
     @warn_err.empty?
   end
 
-  failure_message {
+  failure_message do
     "#{@recipe} emitted warnings and errors!\n#{@warn_err}"
-  }
+  end
 
   supports_block_expectations
 end
