@@ -7,8 +7,8 @@ RSpec::Matchers.define :be_public_key_for do |private_key, pass_phrase|
       private_key, private_key_format = Cheffish::KeyFormatter.decode(IO.read(File.expand_path(private_key)), pass_phrase, private_key)
     end
 
-    encrypted = public_key.public_encrypt('hi there')
-    expect(private_key.private_decrypt(encrypted)).to eq('hi there')
+    encrypted = public_key.public_encrypt("hi there")
+    expect(private_key.private_decrypt(encrypted)).to eq("hi there")
   end
 end
 
@@ -21,9 +21,9 @@ RSpec::Matchers.define :match_private_key do |expected, pass_phrase|
       actual, format = Cheffish::KeyFormatter.decode(IO.read(File.expand_path(actual)), pass_phrase, actual)
     end
 
-    encrypted = actual.public_encrypt('hi there')
-    expect(expected.private_decrypt(encrypted)).to eq('hi there')
-    encrypted = expected.public_encrypt('hi there')
-    expect(actual.private_decrypt(encrypted)).to eq('hi there')
+    encrypted = actual.public_encrypt("hi there")
+    expect(expected.private_decrypt(encrypted)).to eq("hi there")
+    encrypted = expected.public_encrypt("hi there")
+    expect(actual.private_decrypt(encrypted)).to eq("hi there")
   end
 end
